import {Chalk} from "chalk";
import {Inquirer} from "inquirer";
import {Cyan, Documentation, DocUsage, Execute, Glob, IAutoInquire, IAutomapper} from "./Typings";

export = async function (chalk: Chalk, inquirer: Inquirer, autoInquirer: IAutoInquire, autoMap: IAutomapper, execute: Execute): Promise<Cyan> {

    let answers: object = await inquirer.prompt([
        {
            type: "list",
            name: "predicate",
            choices: ["Typescript", "Javascript"],
            message: "What language do you want the cyan.config file to be in? (This only affects the templater, not the actual template!)"
        }
    ]);
    let glob: Glob[] = [];

    let isTypescript: boolean = answers["predicate"] === "Typescript";

    if (isTypescript) {
        glob.push({root: "./Template/typescript", pattern: "**/*.*", ignore: ""});
    } else {
        glob.push({root: "./Template/javascript", pattern: "**/*.*", ignore: ""});
    }
    glob.push({root: "./Template/common", pattern: "**/*.*", ignore: ""});

    let doc: DocUsage = {license: true, git: true, readme: true, contributing: true, semVer: true};
    let docs: Documentation = await autoInquirer.InquireDocument(doc);

    let npm: object = {};
    if (isTypescript) npm = await autoInquirer.InquireInput({"package-name": ["cyanprint-cyanprint", "Please enter the name of npm package"]});
    if (docs.usage.git) npm["git"] = docs.data.gitURL;


    return {
        globs: glob,
        variable: npm,
        npm: isTypescript,
        flags: {
            gitignore: true
        },
        docs: docs
    } as Cyan;
}
